@@ -40,4 +40,4 @@ def test_comments_with_iterators(datadir):
     wb = load_workbook('comments.xlsx', read_only=True)
     ws = wb['Sheet1']
     with pytest.raises(AttributeError):
-        assert ws.cell(coordinate="A1").comment.author == "Cuke"
+        assert ws["A1"].comment.author == "Cuke"
